Crate window_of_opportunity

Crate window_of_opportunity 

Window Of Opportunity

window_of_opportunity is a simple (at the moment) library for managing UIs. Currently it only works in win32, but I plan to work with MacOS and Linux in the near future.

It will ultimately support different controls to display in a window, and have a nice interface for doing so, but currently it’s just a blank window that can be drawn on with an onPaint event handler.

Re-exports

pub use self::win::Win;

Modules

dc
kbd
mouse
win
win_create_args

Macros

default_win_impl

Structs

BaseWin
CommandEvent
Event
An Event struct is what is passed as an abstraction instead of the wndproc args
WPApp

Enums

EventHandled
Determines if an event handler handled the event
SendMessageParams
SourceType

Functions

hword
Get the high word from a 64 bit word. Note this will not be public ultimately, as it’s really just a utility function
load_cursor
load_icon
lword
Get the lower word from a 64 bit word. Note this will not be public ultimately, as it’s really just a utility function